@@ -1,7 +1,7 @@
 import { type ReactElement } from 'react';
 
 import { AddToDashboardForm } from 'app/features/dashboard-scene/addToDashboard/AddToDashboardForm';
-import { useSelector } from 'app/types';
+import { useSelector } from 'app/types/store';
 
 import { getExploreItemSelector } from '../../state/selectors';
 
